@@ -44,6 +44,7 @@ test_that("make_results_row()"
         , "est_indiv"
         , "est_rho"
         , "test_between"
+        , "test_within"
         , "gof"
         , "gof_group"
         , "gof_indiv"
@@ -142,6 +143,26 @@ test_that("make_results_row()"
       )
     )
 
+    expect_identical(
+      column_classes$test_within
+      , expected = list(
+        condition = "character"
+        , parameter1 = "character"
+        , parameter2 = "character"
+        , core1 = "logical"
+        , core2 = "logical"
+        , est = "numeric"
+        , se = "numeric"
+        , statistic = "numeric"
+        , df = "numeric"
+        , p = "numeric"
+        , ci_0.025 = "numeric"
+        , ci_0.1 = "numeric"
+        , ci_0.9 = "numeric"
+        , ci_0.975 = "numeric"
+      )
+    )
+
     expect_identical(
       column_classes$gof
       , expected = list(
